diff --git a/cmake/thisdd4hep_only.csh b/cmake/thisdd4hep_only.csh
index 38807a4de6368d0cf3749d5ae008ab043dcd0a82..425d5f5fb89f03b4595c6644002dea076b170746 100644
--- a/cmake/thisdd4hep_only.csh
+++ b/cmake/thisdd4hep_only.csh
@@ -2,7 +2,7 @@
 # This version of the script has been modified to set up environment variables for
 # only DD4hep.
 #
-# This script if for the csh like shells, see thisdd4hep.sh for bash like shells.
+# This script if for the csh like shells, see thisdd4hep_only.sh for bash like shells.
 #
 # Author: Pere Mato
 
diff --git a/cmake/thisdd4hep_only.sh b/cmake/thisdd4hep_only.sh
index 5b9ce5f959c574bca93716a4ee25c55947403cf6..d776741649d060036b902147a0274a11163ba3a4 100644
--- a/cmake/thisdd4hep_only.sh
+++ b/cmake/thisdd4hep_only.sh
@@ -8,23 +8,19 @@
 # Author: Pere Mato. F. Gaede, M.Frank
 #-------------------------------------------------------------------------------
 #
 #echo " ### thisdd4hep.sh:   initialize the environment for DD4hep ! " 
 #
 #-----------------------------------------------------------------------------
 dd4hep_parse_this()   {
     package=${2};
     if [ "x${1}" = "x" ]; then
-	if [ ! -f bin/this${package}.sh ]; then
-            echo ERROR: must "cd where/${package}/is" before calling ". bin/this${package}.sh" for this version of bash!;
+	if [ ! -f bin/this${package}_only.sh ]; then
+            echo ERROR: must "cd where/${package}/is" before calling ". bin/this${package}_only.sh" for this version of bash!;
             return 1;
 	fi
 	THIS="${PWD}";
     else
-	# get param to "."
 	THIS=$(dirname $(dirname ${1}));
-	#if [ ! -f ${THIS}/bin/this${package}.sh ]; then
-	#    THIS=$(dirname ${package});
-	#fi;
     fi;
     THIS=$(cd ${THIS} > /dev/null; pwd);
 }
@@ -39,7 +35,6 @@ dd4hep_add_path()   {
 	path_value=${path_prefix};
     fi; 
     eval export ${path_name}=${path_value};
-    ## echo "dd4hep_add_path: ${path_name}=${path_value}";
 }
 #-----------------------------------------------------------------------------
 dd4hep_add_library_path()    {
@@ -8,23 +8,19 @@
 #-------------------------------------------------------------------------------
 #
-#echo " ### thisdd4hep.sh:   initialize the environment for DD4hep ! " 
+#echo " ### thisdd4hep_only.sh:   initialize the environment for DD4hep ! " 
 #
 #-----------------------------------------------------------------------------